@@ -19,31 +19,34 @@
 
 #include "productmapping.h"
 
-#include "bugzillalib.h"
-
-#include "drkonqi.h"
-#include "crashedapplication.h"
-
 #include <KConfig>
 #include <KConfigGroup>
 #include <KDebug>
 
-ProductMapping::ProductMapping(const QString & appName, BugzillaManager * bzManager, QObject * parent)
-    : QObject(parent)
-{
-    m_bugzillaManagerPtr = bzManager;
-    //Get valid versions using a delayed check after login
-    connect(m_bugzillaManagerPtr, SIGNAL(loginFinished(bool)), this, SLOT(delayedLoginCheck(bool)));
-    connect(m_bugzillaManagerPtr, SIGNAL(checkVersionsForProductFinished(QStringList)), this,
-                                                            SLOT(checkValidVersions(QStringList)));
+#include "bugzillalib.h"
+#include "crashedapplication.h"
 
+ProductMapping::ProductMapping(const CrashedApplication * crashedApp, BugzillaManager * bzManager, QObject * parent)
+    : QObject(parent)
+    , m_crashedAppPtr(crashedApp)
+    , m_bugzillaManagerPtr(bzManager)
+    , m_bugzillaProductDisabled(false)
+    , m_bugzillaVersionDisabled(false)
+
+{
     //Default "fallback" values
-    m_bugzillaProduct = appName;
+    m_bugzillaProduct = crashedApp->fakeExecutableBaseName();
     m_bugzillaComponent = QLatin1String("general");
     m_bugzillaVersionString = QLatin1String("unspecified");
     m_relatedBugzillaProducts = QStringList() << m_bugzillaProduct;
 
-    map(appName);
+    map(crashedApp->fakeExecutableBaseName());
+
+    //Get valid versions
+    connect(m_bugzillaManagerPtr, SIGNAL(productInfoFetched(Product)),
+            this, SLOT(checkProductInfo(Product)));
+
+    m_bugzillaManagerPtr->fetchProductInfo(m_bugzillaProduct);
 }
 
 void ProductMapping::map(const QString & appName)
@@ -118,26 +121,37 @@ void ProductMapping::getRelatedProductsUsingInternalFile(const QString & bugzill
     }
 }
 
-void ProductMapping::delayedLoginCheck(bool logged)
+void ProductMapping::checkProductInfo(const Product & product)
 {
-    if (logged) {
-        m_bugzillaManagerPtr->checkVersionsForProduct(m_bugzillaProduct);
-    }
-}
+    // check whether the product itself is disabled for new reports,
+    // which usually means that product/application is unmaintained.
+    m_bugzillaProductDisabled = !product.isActive();
 
-void ProductMapping::checkValidVersions(const QStringList & versionList)
-{
-    const QString version = DrKonqi::crashedApplication()->version();
-    if (versionList.contains(version)) {
+    // check whether the product on bugzilla contains the expected component
+    if (! product.components().contains(m_bugzillaComponent)) {
+        m_bugzillaComponent = QLatin1String("general");
+    }
+
+    // find the appropriate version to use on bugzilla
+    const QString version = m_crashedAppPtr->version();
+    const QStringList& allVersions = product.allVersions();
+
+    if (allVersions.contains(version)) {
         //The version the crash application provided is a valid bugzilla version: use it !
         m_bugzillaVersionString = version;
     } else if (version.endsWith(QLatin1String(".00"))) {
         //check if there is a version on bugzilla with just ".0"
         const QString shorterVersion = version.left(version.size() - 1);
-        if (versionList.contains(shorterVersion)) {
+        if (allVersions.contains(shorterVersion)) {
             m_bugzillaVersionString = shorterVersion;
         }
     }
+
+    // check whether that verions is disabled for new reports, which
+    // usually means that version is outdated and not supported anymore.
+    const QStringList& inactiveVersions = product.inactiveVersions();
+    m_bugzillaVersionDisabled = inactiveVersions.contains(m_bugzillaVersionString);
+
 }
 
 QStringList ProductMapping::relatedBugzillaProducts() const
@@ -160,3 +174,12 @@ QString ProductMapping::bugzillaVersion() const
     return m_bugzillaVersionString;
 }
 
+bool ProductMapping::bugzillaProductDisabled() const
+{
+    return m_bugzillaProductDisabled;
+}
+
+bool ProductMapping::bugzillaVersionDisabled() const
+{
+    return m_bugzillaVersionDisabled;
+}
