@@ -42,7 +42,6 @@ class KTimeout;
 
 // @Private
 class KWalletTransaction;
-class KWalletSyncTimer;
 class KWalletSessionStore;
 
 class KWalletD : public QObject, protected QDBusContext {
@@ -244,6 +243,8 @@ class KWalletD : public QObject, protected QDBusContext {
 		// sessions
 		KWalletSessionStore _sessions;
         QDBusServiceWatcher _serviceWatcher;
+
+        bool _useGpg;
 };
 
 
