@@ -37,10 +37,15 @@ QImageItem::~QImageItem()
 
 void QImageItem::setImage(const QImage &image)
 {
+    bool oldImageNull = m_image.isNull();
     m_image = image;
     update();
     emit nativeWidthChanged();
     emit nativeHeightChanged();
+    emit imageChanged();
+    if (oldImageNull != m_image.isNull()) {
+        emit nullChanged();
+    }
 }
 
 QImage QImageItem::image() const
@@ -100,6 +105,7 @@ void QImageItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
     painter->setRenderHint(QPainter::Antialiasing, m_smooth);
     painter->setRenderHint(QPainter::SmoothPixmapTransform, m_smooth);
 
+    QRect sourceRect = m_image.rect();
     QRect destRect;
     switch (m_fillMode) {
     case PreserveAspectFit: {
@@ -107,13 +113,13 @@ void QImageItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
 
         scaled.scale(boundingRect().size().toSize(), Qt::KeepAspectRatio);
         destRect = QRect(QPoint(0, 0), scaled);
+        destRect.moveCenter(boundingRect().center().toPoint());
         break;
     }
     case PreserveAspectCrop: {
-        painter->setClipRect(boundingRect(), Qt::IntersectClip);
-        QSize scaled = m_image.size();
-        scaled.scale(boundingRect().size().toSize(), Qt::KeepAspectRatioByExpanding);
-        destRect = QRect(QPoint(0, 0), scaled);
+        destRect = boundingRect().toRect();
+        sourceRect = destRect;
+        sourceRect.moveCenter(m_image.rect().center());
         break;
     }
     case TileVertically: {
@@ -137,11 +143,15 @@ void QImageItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
     if (m_fillMode >= Tile) {
         painter->drawTiledPixmap(destRect, QPixmap::fromImage(m_image));
     } else {
-        painter->drawImage(destRect, m_image, m_image.rect());
+        painter->drawImage(destRect, m_image, sourceRect);
     }
 
     painter->restore();
 }
 
+bool QImageItem::isNull() const
+{
+    return m_image.isNull();
+}
 
 #include "qimageitem.moc"
